@@ -72,7 +72,7 @@ class CiCd:
 
     def sync_folder_with_git(self, github_event, github_sha):
         files = subprocess.check_output(['git', 'diff', '--name-only', github_event, github_sha]).split()
-        folders_with_change = [ PurePath(i).parents[0] for i in files ]
+        folders_with_change = [ PurePath(i.decode()).parents[0] for i in files ]
         for i in folders_with_change:
             self.deploy_challenge(i)
 
