@@ -14,9 +14,9 @@ def ssh(challenge, host, network="bridge"):
     path = str(Path(challenge.file_path).parent.absolute())
     if os.path.exists(f"{path}/docker-compose.yml"):
         log.info("Deploying docker-compose")
-        subprocess.run(["docker-compose", "-f", f"{path}/docker-compose.yml", "down"], check=False)
+        subprocess.run(["docker-compose", "-f", f"{path}/docker-compose.yml", "build", "--no-cache"], check=False)
         try:
-            subprocess.run(["docker-compose", "-f", f"{path}/docker-compose.yml", "build"], check=False)
+            subprocess.run(["docker-compose", "-f", f"{path}/docker-compose.yml", "down"], check=False)
             subprocess.run(["docker-compose", "-f", f"{path}/docker-compose.yml", "up", "-d"], check=True)
         except Exception as e:
             log.warning("Docker-compose deployed with problem.")
